@@ -2,7 +2,7 @@
 
 import html
 
-from textflow.db import db
+from textflow.service.base import database as db
 
 
 class Document(db.Model):
@@ -16,3 +16,6 @@ class Document(db.Model):
     def __init__(self, **kwargs):
         super(Document, self).__init__(**kwargs)
         self.text = html.escape(self.text)
+
+    def __getitem__(self, item):
+        return html.unescape(self.text.__getitem__(item))
